@@ -2,6 +2,4 @@ from writer import Writer
 
 
 class TXT(Writer):
-
-    def suffix(self):
-        return 'txt'
+    suffix = 'txt'
